'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var fs = require('fs');
var path = _interopDefault(require('path'));

function promisify(fn, ...args) {
  return new Promise((resolve, reject) => {
    try {
      fn(...args, (err, res) => {
        if (err) reject(err);
        else resolve(res);
      });
    } catch (e) {
      reject(e);
    }
  });
}

function htmlTemplate(options = {}) {
  const { input, output, template } = options;

  const fileName = path.basename(output || input);
  const inputFile = fileName.indexOf('.html') < 0 ? `${fileName}.html` : fileName;

  return {
    name: 'html-scaffold',
    generateBundle(outputOptions) {
      const bundle = outputOptions.file;

      return new Promise((resolve, reject) =>
        fs.readFile(input, (error, buffer) => {
          if (error) return reject(error);

          let html = buffer.toString('utf8');

          if (template) {
            Object.keys(template).forEach(key => {
              const regex = new RegExp(`<%= +${key} +%>`, 'g');
              html = html.replace(regex, template[key]);
            });
          }

          return promisify(fs.writeFile, path.join(path.dirname(bundle), inputFile), html).then(
            () => resolve(),
            err => reject(err),
          );
        }),
      );
    },
  };
}

module.exports = htmlTemplate;
